@@ -45,6 +45,7 @@ OC.L10N.register(
     "cc" : "κοιν.",
     "bcc" : "κρυφή κοιν.",
     "Subject" : "Θέμα",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Σημειώστε ότι η αλληλογραφία προέρχεται από μια μη εξουσιοδοτημένη διεύθυνση, οπότε η απάντησή σας πιθανότατα δεν θα διαβαστεί.",
     "Message …" : "Μήνυμα ...",
     "Saving draft …" : "Αποθήκευση προχείρου ...",
     "Draft saved" : "Το πρόχειρο αποθηκεύτηκε",
@@ -55,19 +56,26 @@ OC.L10N.register(
     "Retry" : "Δοκιμή ξανά",
     "Message sent!" : "Μήνυμα εστάλη!",
     "Reply sent!" : "Η απάντηση στάλθηκε!",
+    "Write another message" : "Γράψτε ένα άλλο μήνυμα",
     "Send" : "Αποστολή",
     "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
+    "Draft: " : "Πρόχειρο:",
+    "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
     "Delete" : "Διαγραφή",
+    "Report this bug" : "Αναφέρετε αυτό το σφάλμα",
+    "Not found" : "Δε βρέθηκε",
     "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
     "Download attachment" : "Λήψη συνημμένου",
     "Save to Files" : "Αποθήκευση στα Αρχεία",
     "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
     "Save all to Files" : "Αποθήκευση όλων στα Αρχεία",
+    "Choose a folder to store the attachments in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε μέσα τα συνημμένα",
     "The images have been blocked to protect your privacy." : "Οι εικόνες έχουν αποκλειστεί για να προστατευθεί η ιδιωτικότητά σας.",
     "New message" : "Νέο μήνυμα",
     "Settings" : "Ρυθμίσεις",
     "Show all folders" : "Εμφάνιση όλων των φακέλων",
     "Collapse folders" : "Σύμπτυξη φακέλων",
+    "Account Settings" : "Ρυθμίσεις λογαριασμού",
     "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
     "Compose new message" : "Σύνταξη νέου μηνύματος",
     "Newer message" : "Νεότερο μήνυμα",
