@@ -41,11 +41,14 @@ OC.L10N.register(
     "Add mail account" : "Lisää sähköpostitili",
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Keyboard shortcuts" : "Pikanäppäimet",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Etsitkö tapaa salata sähköpostisi? Asenna Mailvelope-selainlaajennus!",
     "from" : "Lähettäjä",
     "to" : "Vastaanottaja",
+    "+ cc/bcc" : "+ kopio/piilokopio",
     "cc" : "Kopio",
     "bcc" : "Piilokopio",
     "Subject" : "Aihe",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Huomaa, että viesti saapui noreply-osoitteesta, joten\tvastaustasi ei mitä luultavimmin lueta.",
     "Message …" : "Viesti…",
     "Saving draft …" : "Tallennetaan luonnosta…",
     "Draft saved" : "Luonnos tallennettu",
@@ -82,10 +85,20 @@ OC.L10N.register(
     "New message" : "Uusi viesti",
     "Settings" : "Asetukset",
     "Edit" : "Muokkaa",
+    "Add folder" : "Lisää kansio",
     "Show all folders" : "Näytä kaikki kansiot",
     "Collapse folders" : "Supista kansiot",
+    "Loading …" : "Ladataan…",
+    "{total} messages ({unread} unread)" : "{total} viestiä ({unread} lukematta)",
+    "Mark all as read" : "Merkitse kaikki luetuiksi",
+    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
+    "Add subfolder" : "Lisää alikansio",
     "Could not load your draft" : "Luonnosta ei voitu ladata",
+    "No message selected" : "Viestiä ei ole valittu",
+    "Signature" : "Allekirjoitus",
+    "A signature will be added to the text of new and response messages." : "Allekirjoitus lisätään uusiin viesteihin ja vastausviesteihin.",
     "Account Settings" : "Tilin asetukset",
+    "Mail server" : "Sähköpostipalvelin",
     "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
     "Compose new message" : "Uusi viesti",
     "Newer message" : "Uudempi",
