@@ -16,19 +16,23 @@ OC.L10N.register(
     "Delete permanently" : "Végleges törlés",
     "IMAP web client" : "IMAP web kliens",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Könnyen használható levelező kliens mely a levelező szerveredhez csatlakozik IMAP és SMTP protokolon.",
+    "Auto" : "Automatikus",
     "Name" : "Név",
     "Mail Address" : "E-mail cím",
     "Password" : "Jelszó",
     "Manual" : "Manuális",
+    "IMAP Settings" : "IMAP beállítások",
     "IMAP Host" : "IMAP kiszolgáló",
     "IMAP Security" : "IMAP Biztonság",
     "None" : "Semmi",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP port",
     "IMAP User" : "IMAP felhasználó",
     "IMAP Password" : "IMAP jelszó",
     "SMTP Settings" : "SMTP Beállítások",
     "SMTP Host" : "SMTP kiszolgáló",
+    "SMTP Security" : "SMTP biztonság",
     "SMTP Port" : "SMTP port",
     "SMTP User" : "SMTP felhasználó",
     "SMTP Password" : "SMTP jelszó",
@@ -44,18 +48,29 @@ OC.L10N.register(
     "bcc" : "titkos másolat",
     "Subject" : "Tárgy",
     "Message …" : "Üzenet ...",
+    "Saving draft …" : "Vázlat mentése ...",
+    "Draft saved" : "Vázlat elmentve",
+    "Uploading attachments …" : "Csatolmányok feltöltése ...",
     "Sending …" : "Küldés...",
     "Error sending your message" : "Hiba az üzeneted elküldésekor",
     "Go back" : "Visszalép",
+    "Retry" : "Újra",
     "Message sent!" : "Üzenet elküldve!",
     "Reply sent!" : "Válasz elküldve!",
+    "Write another message" : "Új üzenet írása",
     "Send" : "Küldés",
+    "Uploading {percent}% …" : "Feltöltés {percent}% …",
     "Upload attachment" : "Csatolmány feltöltése",
     "Add attachment from Files" : "Csatolmány hozzáadása a Fájlok közül",
     "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
     "No messages in this folder" : "Nincs üzenet a mappában!",
+    "Draft: " : "Vázlat:",
+    "Mark read" : "Olvasottnak jelöl",
+    "Mark unread" : "Olvasatlannak jelöl",
     "Delete" : "Törlés",
+    "Report this bug" : "A hiba bejelentése",
     "Loading messages" : "Üzenetek betöltése",
+    "Not found" : "Nem található",
     "Could not load your message" : "Nem lehet betölteni az üzenetedet",
     "Import into calendar" : "Betöltés a naptárba",
     "Download attachment" : "Melléklet letöltése",
@@ -65,9 +80,19 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
     "New message" : "Új üzenet",
     "Settings" : "Beállítások",
+    "Edit" : "Szerkesztés",
+    "Add folder" : "Mappa hozzáadás",
     "Show all folders" : "Minden mappa megjelenítése",
     "Collapse folders" : "Mappák összecsukása",
+    "Loading …" : "Töltés ...",
+    "{total} messages ({unread} unread)" : "{total} üzenet ({unread} olvasatlan)",
+    "Mark all as read" : "Az összes megjelölése olvasottként",
+    "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
+    "Add subfolder" : "Almappa hozzáadás",
+    "No message selected" : "Nincs kiválasztott üzenet",
+    "Signature" : "Aláírás",
     "Account Settings" : "Fiók beállítások",
+    "Mail server" : "Levelezőszerver",
     "Speed up your Mail experience with these quick shortcuts." : "Gyorsítsd fel a levelezési élményedet ezekkel a rövidítésekkel.",
     "Compose new message" : "Új üzenet írása",
     "Newer message" : "Újabb üzenet",
