@@ -48,7 +48,7 @@ OC.L10N.register(
     "cc" : "cc",
     "bcc" : "bcc",
     "Subject" : "件名",
-    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "\t返信なしアドレスから送られているため、返信は読まれません。",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "このメールは送信専用のメールアドレスから配信されています\t返信内容の確認はされませんので、ご了承ください。",
     "Message …" : "メッセージ…",
     "Saving draft …" : "下書きを保存しています",
     "Draft saved" : "下書きを保存しました。",
@@ -58,7 +58,7 @@ OC.L10N.register(
     "Go back" : "戻る",
     "Retry" : "再試行",
     "Message sent!" : "へメッセージを送信しました！",
-    "Reply sent!" : "返信送信！",
+    "Reply sent!" : "返信を送信！",
     "Write another message" : "他のメッセージを書く",
     "Send" : "送信",
     "Uploading {percent}% …" : "アップロード中 {percent}% …",
@@ -96,7 +96,7 @@ OC.L10N.register(
     "Could not load your draft" : "下書きを読み込めませんでした",
     "No message selected" : "メッセージが選択されていません。",
     "Signature" : "署名",
-    "A signature will be added to the text of new and response messages." : "新規メッセージおよび応答メッセージのテキストに署名が追加されます。",
+    "A signature will be added to the text of new and response messages." : "新しいメールおよび返信のテキストに署名が追加されます。",
     "Account Settings" : "アカウント設定",
     "Mail server" : "メールサーバー",
     "Speed up your Mail experience with these quick shortcuts." : "ショートカットであなたのメール操作をスピードアップしてください。",
