@@ -2,27 +2,27 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Poczta",
-    "Inbox" : "Odbiorcza",
+    "Inbox" : "Odebrane",
     "Sent" : "Wysłane",
-    "Drafts" : "Szkice",
+    "Drafts" : "Kopie robocze",
     "Archive" : "Archiwum",
     "Trash" : "Kosz",
     "Junk" : "Spam",
     "All" : "Wszystkie",
     "Favorites" : "Ulubione",
-    "Auto detect failed. Please use manual mode." : "Autowykrywanie nie powiodło się. Proszę użyć trybu ręcznego.",
-    "Updating account failed: " : "Błąd aktualizacji konta: ",
-    "Creating account failed: " : "Utworzenie konta nie powiodło się:",
-    "Delete permanently" : "Trwale usuń",
-    "IMAP web client" : "Klient webowy IMAP",
-    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Łatwy w użytkowaniu klient IMAP i SMTP, który łączy się z Twoim serwerem pocztowym.",
-    "Auto" : "Automatycznie",
+    "Auto detect failed. Please use manual mode." : "Automatyczne wykrywanie nie powiodło się. Użyj trybu ręcznego.",
+    "Updating account failed: " : "Aktualizacja konta nie powiodła się: ",
+    "Creating account failed: " : "Utworzenie konta nie powiodło się: ",
+    "Delete permanently" : "Usuń trwale",
+    "IMAP web client" : "Klient internetowy IMAP",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Łatwy w użyciu klient poczty e-mail, który łączy się z serwerem poczty za pośrednictwem IMAP i SMTP.",
+    "Auto" : "Automatyczne",
     "Name" : "Nazwa",
-    "Mail Address" : "Adres mailowy",
+    "Mail Address" : "Adres e-mail",
     "Password" : "Hasło",
-    "Manual" : "Ustawienia własne",
+    "Manual" : "Ręczne",
     "IMAP Settings" : "Ustawienia IMAP",
-    "IMAP Host" : "IMAP Host",
+    "IMAP Host" : "Host IMAP",
     "IMAP Security" : "Zabezpieczenia IMAP",
     "None" : "Brak",
     "SSL/TLS" : "SSL/TLS",
@@ -31,74 +31,74 @@ OC.L10N.register(
     "IMAP User" : "Użytkownik IMAP",
     "IMAP Password" : "Hasło IMAP",
     "SMTP Settings" : "Ustawienia SMTP",
-    "SMTP Host" : "SMTP Host",
+    "SMTP Host" : "Host SMTP",
     "SMTP Security" : "Zabezpieczenia SMTP",
     "SMTP Port" : "Port SMTP",
     "SMTP User" : "Użytkownik SMTP",
     "SMTP Password" : "Hasło SMTP",
     "Save" : "Zapisz",
     "Connect" : "Połącz",
-    "Add mail account" : "Dodaj konto mailowe",
+    "Add mail account" : "Dodaj konto e-mail",
     "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
-    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Szukasz sposobu na szyfrowanie swoich wiadomosci? Zainstaluj rozszerzenie Mailvelope do przeglądarki!",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Szukasz sposobu na szyfrowanie wiadomości e-mail? Zainstaluj dla przeglądarki rozszerzenie Mailvelope!",
     "from" : "od",
     "to" : "do",
     "+ cc/bcc" : "+ DW/UDW",
-    "cc" : "cc",
-    "bcc" : "bcc",
+    "cc" : "DW",
+    "bcc" : "UDW",
     "Subject" : "Temat",
-    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Zwróć uwagę, że wiadomość została wysłana z adresu nie przyjmującego odpowiedzi\tdlatego twoja odpowiedź prawdopodobnie nie zostanie odczytana.",
-    "Message …" : "Wiadomość ...",
-    "Saving draft …" : "Zapisuję szkic ...",
-    "Draft saved" : "Szkic zapisany",
-    "Uploading attachments …" : "Wysyłanie załączników ...",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Zwróć uwagę, że e-mail został wysłany z niepoprawnego adresu,\tdlatego Twoja odpowiedź prawdopodobnie nie zostanie przeczytana.",
+    "Message …" : "Wiadomość...",
+    "Saving draft …" : "Zapisywanie wersji roboczej…",
+    "Draft saved" : "Zapisana wersja robocza",
+    "Uploading attachments …" : "Wysyłanie załączników...",
     "Sending …" : "Wysyłanie…",
-    "Error sending your message" : "W trakcie wysyłania wiadomości wystąpił błąd",
+    "Error sending your message" : "Błąd podczas wysyłania wiadomości",
     "Go back" : "Powrót",
     "Retry" : "Powtórz",
     "Message sent!" : "Wiadomość wysłana!",
     "Reply sent!" : "Odpowiedź została wysłana!",
-    "Write another message" : "Utwórz kolejną wiadomość",
+    "Write another message" : "Napisz kolejną wiadomość",
     "Send" : "Wyślij",
     "Uploading {percent}% …" : "Wysłane {percent}%…",
     "Upload attachment" : "Dodaj załącznik",
-    "Add attachment from Files" : "Dodaj załącznik z Pliki",
-    "Choose a file to add as attachment" : "Wybierz plik aby dodać jako załącznik",
+    "Add attachment from Files" : "Dodaj załącznik z Plików",
+    "Choose a file to add as attachment" : "Wybierz plik, aby dodać jako załącznik",
     "No messages in this folder" : "Brak wiadomości w tym folderze",
-    "Draft: " : "Szkic:",
+    "Draft: " : "Wersja robocza:",
     "Mark read" : "Oznacz jako przeczytana",
     "Mark unread" : "Oznacz jako nie przeczytana",
     "Delete" : "Usuń",
     "Report this bug" : "Zgłoś ten błąd",
-    "Loading messages" : "Pobieranie wiadomości",
-    "Not found" : "Nie odnaleziono",
+    "Loading messages" : "Ładowanie wiadomości",
+    "Not found" : "Nie znaleziono",
     "Could not load your message" : "Nie można załadować wiadomości",
     "Import into calendar" : "Importuj do kalendarza",
     "Download attachment" : "Pobierz załącznik",
-    "Save to Files" : "Zapisz do plików",
-    "Choose a folder to store the attachment in" : "Proszę wybrać folder do zapisania załącznika",
-    "Save all to Files" : "Zapisz wszystko do plików",
-    "Choose a folder to store the attachments in" : "Wybierz folder do zapisywania załączników",
-    "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane by chronić Twoją prywatność.",
-    "Show images from this\tsender" : "Wyświetl zdalną zawartość od\tnadawcy",
+    "Save to Files" : "Zapisz do Plików",
+    "Choose a folder to store the attachment in" : "Wybierz katalog, w którym chcesz zapisać załącznik",
+    "Save all to Files" : "Zapisz wszystko do Plików",
+    "Choose a folder to store the attachments in" : "Wybierz katalog do przechowywania załączników",
+    "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane, aby chronić Twoją prywatność.",
+    "Show images from this\tsender" : "Pokaż obrazy od tego\tnadawcy",
     "New message" : "Nowa wiadomość",
     "Settings" : "Ustawienia",
     "Edit" : "Edycja",
-    "Add folder" : "Dodaj katalog",
-    "Show all folders" : "Wyświetl wszystkie foldery",
+    "Add folder" : "Dodaj folder",
+    "Show all folders" : "Pokaż wszystkie foldery",
     "Collapse folders" : "Zwiń foldery",
     "Loading …" : "Wczytywanie…",
     "{total} messages ({unread} unread)" : "{total} wiadomości ({unread} nieprzeczytane)",
     "Mark all as read" : "Oznacz wszystkie jako przeczytane",
-    "Mark all messages of this folder as read" : "Zaznacz wszystkie wiadomości tego katalogu jako przeczytane",
-    "Add subfolder" : "Dodaj podkatalog",
-    "Could not load your draft" : "Nie można wczytać szkicu wiadomości",
+    "Mark all messages of this folder as read" : "Zaznacz wszystkie wiadomości tego folderu jako przeczytane",
+    "Add subfolder" : "Dodaj podfolder",
+    "Could not load your draft" : "Nie można załadować wersji roboczej",
     "No message selected" : "Nie wybrano żadnej wiadomości",
     "Signature" : "Podpis",
     "A signature will be added to the text of new and response messages." : "Podpis będzie dodany do nowych i zwrotnych wiadomości.",
     "Account Settings" : "Ustawienia konta",
-    "Mail server" : "Serwer pocztowy",
+    "Mail server" : "Serwer poczty",
     "Speed up your Mail experience with these quick shortcuts." : "Aby przyspieszyć korzystanie z Poczty użyj tych skrótów.",
     "Compose new message" : "Napisz nową wiadomość",
     "Newer message" : "Nowsza wiadomość",
@@ -113,12 +113,12 @@ OC.L10N.register(
     "Nextcloud Mail" : "Poczta Nextcloud",
     "All inboxes" : "Wszystkie skrzynki odbiorcze",
     "Could not load {tag}{name}{endtag}" : "Nie można załadować {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Podczas ładowania wystąpił problem {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Wystąpił problem podczas ładowania {tag}{name}{endtag}",
     "Could not load the desired message" : "Nie można wczytać żądanej wiadomości",
     "Could not load the message" : "Nie można załadować wiadomości",
     "Error loading message" : "Błąd podczas ładowania wiadomości",
-    "Forwarding to %s" : "Prześlij do %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Kliknij tutaj, jeśli nie są automatycznie przekierowywane w ciągu kilku sekund.",
+    "Forwarding to %s" : "Przekierowanie do %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Kliknij tutaj, jeśli nie zostaniesz automatycznie przekierowany w ciągu kilku sekund.",
     "Redirect" : "Przekieruj",
     "The link leads to %s" : "Link prowadzi do %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
