@@ -14,23 +14,34 @@ OC.L10N.register(
     "Updating account failed: " : "更新帳戶失敗",
     "Creating account failed: " : "建立帳號失敗：",
     "Delete permanently" : "永久刪除",
+    "IMAP web client" : "IMAP客戶端",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "一個簡易的電子郵件程式，透過IMAP與SMTP功能與郵件伺服器同步",
+    "Auto" : "自動",
     "Name" : "名字",
     "Mail Address" : "郵件地址",
     "Password" : "密碼",
+    "Manual" : "手動",
+    "IMAP Settings" : "IMAP設定",
     "IMAP Host" : "IMAP 主機",
+    "IMAP Security" : "IMAP Security",
     "None" : "無",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP 連接埠",
     "IMAP User" : "IMAP 帳號",
     "IMAP Password" : "IMAP 密碼",
+    "SMTP Settings" : "SMTP設定",
     "SMTP Host" : "SMTP 主機",
+    "SMTP Security" : "SMTP Security",
     "SMTP Port" : "SMTP 連接埠",
     "SMTP User" : "SMTP 帳號",
     "SMTP Password" : "SMTP 密碼",
+    "Save" : "儲存",
     "Connect" : "連線",
     "Add mail account" : "新增郵件帳戶",
     "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
     "Keyboard shortcuts" : "快速鍵",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "需要一個方式加密您的電子郵件嗎？請安裝 Mailvelope 瀏覽器擴充程式",
     "from" : "自",
     "to" : "至",
     "cc" : "副本",
